@@ -14,7 +14,6 @@ import logging
 import re
 from urllib.parse import urlparse
 from prettytable import PrettyTable, ALL
-import setup
 
 
 # yaml 数据模型
@@ -1444,7 +1443,7 @@ def main(argvs=None):
     elif command == "clean":
         yhgit().clean()
     elif command == "version":
-        debugInfo(setup.version)
+        debugInfo("version 2.3")
     elif command == "help" or command == "-h":
 
         """
